==> lxqt-notificationd_1.2.0.orig.tar.xz: lxqt-notificationd-1.2.0/config/translations/lxqt-config-notificationd_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>AdvancedSettings</name>
    <message>
        <location filename="../advancedsettings.ui" line="67"/>
        <source>Sizes</source>
        <translation>Tailles</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="75"/>
        <source>Width:</source>
        <translation>Largeur :</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="82"/>
        <location filename="../advancedsettings.ui" line="106"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="99"/>
        <source>Spacing:</source>
        <translation>Espace :</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="118"/>
        <source>Duration</source>
        <translation>Durée</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="130"/>
        <source>Some notifications set their own on-screen duration.</source>
        <translation>Certaines notifications possèdent leur propre durée.</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="142"/>
        <source>Default duration:</source>
        <translation>Durée par défaut :</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="149"/>
        <source> sec</source>
        <translation> sec</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="177"/>
        <source>Screen</source>
        <translation>Écran</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="183"/>
        <source>When unchecked the notification will always show on primary screen</source>
        <translation>Lorsque la case n&apos;est pas cochée, les notifications s&apos;afficheront toujours sur l&apos;écran principal</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="186"/>
        <source>Show notifications on screen with the mouse</source>
        <translation>Afficher les notifications sur l&apos;écran où se trouve la souris</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="196"/>
        <source>Do Not Disturb</source>
        <translation>Ne Pas Déranger</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="202"/>
        <source>Only save notifications</source>
        <translation>Enregistrer uniquement les notifications</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="17"/>
        <source>Unattended Notifications</source>
        <translation>Notifications sans surveillance</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="25"/>
        <source>How many to save:</source>
        <translation>Combien à sauvegarder :</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="39"/>
        <location filename="../advancedsettings.ui" line="49"/>
        <source>Application name is on the top of notification.</source>
        <translation>Le nom de l&apos;application est en haut de la notification.</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="42"/>
        <source>Ignore these applications:</source>
        <translation>Ignorer ces applications :</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="52"/>
        <source>app1,app2,app3</source>
        <translation>app1,app2,app3</translation>
    </message>
</context>
<context>
    <name>BasicSettings</name>
    <message>
        <location filename="../basicsettings.ui" line="17"/>
        <source>Position on screen</source>
        <translation>Position à l&apos;écran</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="176"/>
        <source>Preview</source>
        <translation>Aperçu</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="63"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; notifications daemon is slow to respond.
Keep trying to connect…</source>
        <translation>&lt;b&gt;Avertissement&#xa0;:&lt;/b&gt;Le démon de notifications est lent à répondre.
Continuez d’essayer de vous connecter…</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="72"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; No notifications daemon is running.
A fallback will be used.</source>
        <translation>&lt;b&gt;Attention :&lt;/b&gt; Aucun processus de notification n&apos;est en cours d&apos;exécution.
Un processus par défaut sera utilisé.</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="75"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; A third-party notifications daemon (%1) is running.
These settings won&apos;t have any effect on it!</source>
        <translation>&lt;b&gt;Attention :&lt;/b&gt; Un autre processus de notification (%1) est actif.
Ces réglages n&apos;auront aucun effet sur lui !</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="137"/>
        <source>at top left</source>
        <translation>en haut à gauche</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="139"/>
        <source>at top center</source>
        <translation>en haut au centre</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="141"/>
        <source>at top right</source>
        <translation>en haut à droite</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="143"/>
        <source>at center left</source>
        <translation>au centre gauche</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="145"/>
        <source>at center right</source>
        <translation>au centre droit</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="147"/>
        <source>at bottom left</source>
        <translation>en bas à gauche</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="149"/>
        <source>at bottom center</source>
        <translation>en bas au centre</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="151"/>
        <source>at bottom right</source>
        <translation>en bas à droite</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="153"/>
        <source>Notification demo </source>
        <translation>Démo de notification </translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="154"/>
        <source>This is a test notification.
 All notifications will now appear here on LXQt.</source>
        <translation>Ceci est un test de notification.
Toutes les notifications vont maintenant être affichées ici, sur LXQt.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="41"/>
        <source>Desktop Notifications</source>
        <translation>Notifications du bureau</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="44"/>
        <source>General Settings</source>
        <translation>Réglages généraux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="48"/>
        <source>Position</source>
        <translation>Position</translation>
    </message>
</context>
</TS>

==> lxqt-notificationd_2.1.1.orig.tar.xz: lxqt-notificationd-2.1.1/config/translations/lxqt-config-notificationd_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>AdvancedSettings</name>
    <message>
        <location filename="../advancedsettings.ui" line="67"/>
        <source>Duration</source>
        <translation>Durée</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="79"/>
        <source>Some notifications set their own on-screen duration.</source>
        <translation>Certaines notifications possèdent leur propre durée.</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="91"/>
        <source>Default duration:</source>
        <translation>Durée par défaut :</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="98"/>
        <source> sec</source>
        <translation> sec</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="126"/>
        <source>Screen</source>
        <translation>Écran</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="132"/>
        <source>When unchecked the notification will always show on primary screen</source>
        <translation>Lorsque la case n&apos;est pas cochée, les notifications s&apos;afficheront toujours sur l&apos;écran principal</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="135"/>
        <source>Show notifications on screen with the mouse</source>
        <translation>Afficher les notifications sur l&apos;écran où se trouve la souris</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="145"/>
        <source>Do Not Disturb</source>
        <translation>Ne Pas Déranger</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="151"/>
        <source>Only save notifications</source>
        <translation>Enregistrer uniquement les notifications</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="17"/>
        <source>Unattended Notifications</source>
        <translation>Notifications sans surveillance</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="25"/>
        <source>How many to save:</source>
        <translation>Combien à sauvegarder :</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="39"/>
        <location filename="../advancedsettings.ui" line="49"/>
        <source>Application name is on the top of notification.</source>
        <translation>Le nom de l&apos;application est en haut de la notification.</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="42"/>
        <source>Ignore these applications:</source>
        <translation>Ignorer ces applications :</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="52"/>
        <source>app1,app2,app3</source>
        <translation>app1,app2,app3</translation>
    </message>
</context>
<context>
    <name>BasicSettings</name>
    <message>
        <location filename="../basicsettings.ui" line="17"/>
        <source>Sizes</source>
        <translation>Tailles</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="25"/>
        <source>Width:</source>
        <translation>Largeur :</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="32"/>
        <location filename="../basicsettings.ui" line="56"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="49"/>
        <source>Spacing:</source>
        <translation>Espace :</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="68"/>
        <source>Position on screen</source>
        <translation>Position à l&apos;écran</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="227"/>
        <source>Preview</source>
        <translation>Aperçu</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="65"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; notifications daemon is slow to respond.
Keep trying to connect…</source>
        <translation>&lt;b&gt;Avertissement&#xa0;:&lt;/b&gt;Le démon de notifications est lent à répondre.
Continuez d’essayer de vous connecter…</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="74"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; No notifications daemon is running.
A fallback will be used.</source>
        <translation>&lt;b&gt;Attention :&lt;/b&gt; Aucun processus de notification n&apos;est en cours d&apos;exécution.
Un processus par défaut sera utilisé.</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="77"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; A third-party notifications daemon (%1) is running.
These settings won&apos;t have any effect on it!</source>
        <translation>&lt;b&gt;Attention :&lt;/b&gt; Un autre processus de notification (%1) est actif.
Ces réglages n&apos;auront aucun effet sur lui !</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="142"/>
        <source>at top left</source>
        <translation>en haut à gauche</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="144"/>
        <source>at top center</source>
        <translation>en haut au centre</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="146"/>
        <source>at top right</source>
        <translation>en haut à droite</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="148"/>
        <source>at center left</source>
        <translation>au centre gauche</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="150"/>
        <source>at center right</source>
        <translation>au centre droit</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="152"/>
        <source>at bottom left</source>
        <translation>en bas à gauche</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="154"/>
        <source>at bottom center</source>
        <translation>en bas au centre</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="156"/>
        <source>at bottom right</source>
        <translation>en bas à droite</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="158"/>
        <source>Notification demo </source>
        <translation>Démo de notification </translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="159"/>
        <source>This is a test notification.
 All notifications will now appear here on LXQt.</source>
        <translation>Ceci est un test de notification.
Toutes les notifications vont maintenant être affichées ici, sur LXQt.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="41"/>
        <source>Desktop Notifications</source>
        <translation>Notifications du bureau</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="44"/>
        <source>General Settings</source>
        <translation>Réglages généraux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="48"/>
        <source>Appearance</source>
        <translation>Apparence</translation>
    </message>
</context>
</TS>
